@@ -52,6 +52,13 @@ QList<KXSConfigItem*> KXSXml::items() const
     return QList<KXSConfigItem*>();
 }
 
+QString KXSXml::name() const
+{
+    if ( handler )
+        return handler->name();
+    return QString();
+}
+
 QString KXSXml::description() const
 {
     if ( handler )
@@ -107,6 +114,8 @@ bool KXSXmlHandler::startElement( const QString&, const QString&,
 	    i = new KXSFileControl( parent, id, atts );
 	else
 	    i = new KXSStringItem( id, atts );
+    } else if ( qName == "screensaver" ) {
+        mName = atts.value( "_label" );
     } else if ( qName == "_description" ) {
 	inDesc = true;
     } else if ( qName == "select" ) {
@@ -151,7 +160,7 @@ bool KXSXmlHandler::endElement( const QString&, const QString&, const QString &q
 bool KXSXmlHandler::characters( const QString &ch )
 {
     if ( inDesc )
-	desc += ch;
+	mDesc += ch;
     return true;
 }
 
