@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.cpp 489039 2005-12-16 22:05:28Z giessl $
+ *	$Id: cdeclient.cpp 922431 2009-02-07 01:12:28Z schwarzer $
  *
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -7,7 +7,7 @@
  *	Copyright (c) 2000-2001, 2002
  *		Chris Lee       <lee@azsites.com>
  *		Lennart Kudling <kudling@kde.org>
- *      	Fredrik Hglund <fredrik@kde.org>
+ *      	Fredrik Höglund <fredrik@kde.org>
  *
  *	Copyright (c) 2003,2004
  *		Luciano Montanaro <mikelima@cirulla.net>
@@ -20,13 +20,23 @@
 #include "cdeclient.h"
 #include <qdatetime.h>
 #include <qlayout.h>
-#include <qbutton.h>
+#include <q3button.h>
 #include <qcursor.h>
 #include <qlabel.h>
 #include <qtooltip.h>
 #include <qdrawutil.h>
 #include <qpainter.h>
 #include <qapplication.h>
+//Added by qt3to4:
+#include <QPaintEvent>
+#include <Q3PointArray>
+#include <QEvent>
+#include <QBoxLayout>
+#include <Q3ValueList>
+#include <QShowEvent>
+#include <QVBoxLayout>
+#include <QResizeEvent>
+#include <QMouseEvent>
 #include <klocale.h>
 #include <kconfig.h>
 
@@ -125,7 +135,7 @@ static void fixColorGroup(QColorGroup & colorGroup)
     if (value < 128)
     {
       light.setHsv(hue, saturation, 128);
-      colorGroup.setColor(QColorGroup::Light, light);
+      colorGroup.setColor(QPalette::Light, light);
     }
 
     QColor dark = colorGroup.dark();
@@ -135,7 +145,7 @@ static void fixColorGroup(QColorGroup & colorGroup)
     if (value < 84)
     {
       dark.setHsv(hue, saturation, 84);
-      colorGroup.setColor(QColorGroup::Dark, dark);
+      colorGroup.setColor(QPalette::Dark, dark);
     }
 }
 
@@ -153,8 +163,8 @@ static void readConfig(CdeClientFactory *f)
     KConfig conf( "kwincderc" );
 
     conf.setGroup("General");
-    coloredFrame = conf.readBoolEntry( "UseTitleBarBorderColors", true );
-    titlebarButtonMode = conf.readBoolEntry( "TitlebarButtonMode", true );
+    coloredFrame = conf.readEntry( "UseTitleBarBorderColors", true );
+    titlebarButtonMode = conf.readEntry( "TitlebarButtonMode", true );
 
     QString value = conf.readEntry( "TextAlignment", "AlignHCenter" );
     if ( value == "AlignLeft" )
@@ -248,11 +258,11 @@ bool CdeClientFactory::supports( Ability ability )
     };
 }
 
-QValueList< CdeClientFactory::BorderSize >
+Q3ValueList< CdeClientFactory::BorderSize >
 CdeClientFactory::borderSizes() const
 {
     // the list must be sorted
-    return QValueList< BorderSize >() << BorderTiny << BorderNormal <<
+    return Q3ValueList< BorderSize >() << BorderTiny << BorderNormal <<
 	BorderLarge << BorderVeryLarge <<  BorderHuge <<
 	BorderVeryHuge << BorderOversized;
 }
@@ -287,7 +297,7 @@ void CdeClient::init()
     {
 	// but if the frame is set to just 1 pixel we just draw the black frame
 	// instead of the normal window frame, so no extra space is needed. if
-	// its 0 we don't draw anything.
+	// it is 0 we don't draw anything.
     	mainLayout->setMargin( s_frameWidth );
     }
 
@@ -325,7 +335,7 @@ void CdeClient::addClientButtons( const QString& s )
                 case 'M':
                     if ( ! button[BtnMenu] )
                     {
-                        button[BtnMenu] = new CdeButton( this, "menu", BtnMenu, i18n("Menu"), LeftButton|RightButton );
+                        button[BtnMenu] = new CdeButton( this, "menu", BtnMenu, i18n("Menu"), Qt::LeftButton|Qt::RightButton );
                         connect( button[BtnMenu], SIGNAL(pressed()), SLOT(menuButtonPressed()) );
                         connect( button[BtnMenu], SIGNAL(released()), SLOT(menuButtonReleased()) );
                         titleLayout->addWidget( button[BtnMenu] );
@@ -358,7 +368,7 @@ void CdeClient::addClientButtons( const QString& s )
                 case 'A':
                     if ( (! button[BtnMax] ) && isMaximizable() )
                     {
-                        button[BtnMax] = new CdeButton(this, "maximize", BtnMax, i18n("Maximize"), LeftButton|MidButton|RightButton);
+                        button[BtnMax] = new CdeButton(this, "maximize", BtnMax, i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
                         connect(button[BtnMax], SIGNAL(clicked()),
 				SLOT(maximizeButtonClicked()));
                         titleLayout->addWidget( button[BtnMax] );
@@ -397,7 +407,7 @@ void CdeClient::maximizeChange()
     if ( button[BtnMax] ) {
 	bool m = maximizeMode() == MaximizeFull;
 	QToolTip::remove(button[BtnMax]);
-	QToolTip::add(button[BtnMax], m ? i18n("Restore") : i18n("Maximize"));
+	button[BtnMax]->setToolTip( m ? i18n("Restore") : i18n("Maximize"));
 	button[BtnMax]->repaint();
     }
 }
@@ -477,10 +487,10 @@ void CdeClient::resizeEvent( QResizeEvent* e)
         int dy = 0;
 
 	    if ( e->oldSize().width() != width() )
-	       dx = 32 + QABS( e->oldSize().width() -  width() );
+	       dx = 32 + qAbs( e->oldSize().width() -  width() );
 
 	    if ( e->oldSize().height() != height() )
-	       dy = 8 + QABS( e->oldSize().height() -  height() );
+	       dy = 8 + qAbs( e->oldSize().height() -  height() );
 
 	    if ( dy )
 	       widget()->update( 0, height() - dy + 1, width(), dy );
@@ -657,7 +667,7 @@ void CdeClient::paintEvent( QPaintEvent* )
     p.setPen( options()->color( KDecoration::ColorFont, isActive() ) );
     if ( p.fontMetrics().width( caption() ) > trect.width() - 6 )
     {
-	// left align the text if its too wide to fit in the titlebar
+	// left align the text if it is too wide to fit in the titlebar
 	p.drawText( trect.x() + 3, trect.y(),
 	    trect.width() - 6, trect.height(),
 	    AlignLeft | AlignVCenter, caption() );
@@ -712,19 +722,13 @@ KDecoration::Position CdeClient::mousePosition( const QPoint& p ) const
 
 void CdeClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
-void CdeClient::wheelEvent( QWheelEvent * e )
-{
-    if (isSetShade() || titleLayout->geometry().contains( e->pos() ) )
-        titlebarMouseWheelOperation( e->delta());
-}
-
 void CdeClient::mousePressEvent( QMouseEvent * e )
 {
-    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
     {
 	if ( titlebarButtonMode )
 	{
@@ -742,7 +746,7 @@ void CdeClient::borders(int &left, int &right, int &top, int &bottom) const
 
 void CdeClient::mouseReleaseEvent( QMouseEvent * e )
 {
-    if ( e->button() == LeftButton && titlebarPressed )
+    if ( e->button() == Qt::LeftButton && titlebarPressed )
     {
 	titlebarPressed = false;
 	widget()->repaint(titlebar->geometry(), false);
@@ -769,9 +773,6 @@ bool CdeClient::eventFilter(QObject *o, QEvent *e)
     case QEvent::Show:
 	showEvent(static_cast< QShowEvent* >(e));
 	return true;
-    case QEvent::Wheel:
-	wheelEvent( static_cast< QWheelEvent* >( e ));
-	return true;
     default:
 	break;
     }
@@ -782,7 +783,7 @@ bool CdeClient::eventFilter(QObject *o, QEvent *e)
 
 CdeButton::CdeButton(CdeClient* parent,
 	const char* name, int btnType, const QString& tip, int realize_btns)
-    : QButton(parent->widget(), name), m_btnType(btnType), last_button(NoButton)
+    : Q3Button(parent->widget(), name), m_btnType(btnType), last_button(Qt::NoButton)
 {
     setBackgroundMode( QWidget::NoBackground );
     setFixedSize( s_buttonSize, s_buttonSize );
@@ -790,7 +791,7 @@ CdeButton::CdeButton(CdeClient* parent,
     m_parent = parent;
 
     setCursor(ArrowCursor);
-    QToolTip::add(this, tip);
+    this->setToolTip( tip);
 
     m_realize_buttons = realize_btns;
 }
@@ -820,9 +821,9 @@ void CdeButton::drawButton( QPainter* p )
 	break;
 	case (BtnHelp):
 	    p->setPen( colorGroup.light() );
-	    p->drawLineSegments( QPointArray(16, helpLLines) );
+	    p->drawLineSegments( Q3PointArray(16, helpLLines) );
 	    p->setPen( colorGroup.dark() );
-	    p->drawLineSegments( QPointArray(14, helpDLines) );
+	    p->drawLineSegments( Q3PointArray(14, helpDLines) );
 	break;
 	case (BtnIconify):
 	    qDrawShadePanel( p, s_o2, s_o2, s_w2, s_w2, colorGroup );
@@ -833,9 +834,9 @@ void CdeButton::drawButton( QPainter* p )
 	break;
 	case (BtnClose):
 	    p->setPen( colorGroup.dark() );
-	    p->drawLineSegments( QPointArray(18, closeDLines) );
+	    p->drawLineSegments( Q3PointArray(18, closeDLines) );
 	    p->setPen( colorGroup.light() );
-	    p->drawLineSegments( QPointArray(15, closeLLines) );
+	    p->drawLineSegments( Q3PointArray(15, closeLLines) );
 	break;
     }
 }
@@ -844,16 +845,16 @@ void CdeButton::mousePressEvent(QMouseEvent *e)
 {
     last_button = e->button();
     QMouseEvent me(e->type(), e->pos(),
-	    e->globalPos(), (e->button()&m_realize_buttons)?LeftButton:NoButton, e->state());
-    QButton::mousePressEvent(&me);
+	    e->globalPos(), (e->button()&m_realize_buttons)?Qt::LeftButton:Qt::NoButton, e->state());
+    Q3Button::mousePressEvent(&me);
 }
 
 void CdeButton::mouseReleaseEvent(QMouseEvent * e)
 {
     last_button = e->button();
     QMouseEvent me(e->type(), e->pos(),
-	    e->globalPos(), (e->button()&m_realize_buttons)?LeftButton:NoButton, e->state());
-    QButton::mouseReleaseEvent(&me);
+	    e->globalPos(), (e->button()&m_realize_buttons)?Qt::LeftButton:Qt::NoButton, e->state());
+    Q3Button::mouseReleaseEvent(&me);
 }
 
 } // CDE namespace
